
// default includes
#include "Global/Macros.h"
CLANG_DIAG_OFF(mismatched-tags)
GCC_DIAG_OFF(unused-parameter)
GCC_DIAG_OFF(missing-field-initializers)
GCC_DIAG_OFF(missing-declarations)
GCC_DIAG_OFF(uninitialized)
GCC_DIAG_UNUSED_LOCAL_TYPEDEFS_OFF
#include <shiboken.h> // produces many warnings
#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QDebug>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <destroylistener.h>
#include <qapp_macro.h>
#include <typeinfo>

// module include
#include "natrongui_python.h"

// main header
#include "natron_python_pyguiapplication_wrapper.h"

// inner classes

// Extra includes
#include <PyAppInstance.h>
#include <PyGuiApp.h>
#include <qpixmap.h>


#include <cctype>
#include <cstring>

QT_WARNING_DISABLE_DEPRECATED
using namespace Natron;



template <class T>
static const char *typeNameOf(const T &t)
{
    const char *typeName =  typeid(t).name();
    auto size = std::strlen(typeName);
#if defined(Q_CC_MSVC) // MSVC: "class QPaintDevice * __ptr64"
    if (auto lastStar = strchr(typeName, '*')) {
        // MSVC: "class QPaintDevice * __ptr64"
        while (*--lastStar == ' ') {
        }
        size = lastStar - typeName + 1;
    }
#else // g++, Clang: "QPaintDevice *" -> "P12QPaintDevice"
    if (size > 2 && typeName[0] == 'P' && std::isdigit(typeName[1])) {
        ++typeName;
        --size;
    }
#endif
    char *result = new char[size + 1];
    result[size] = '\0';
    memcpy(result, typeName, size);
    return result;
}

// Native ---------------------------------------------------------

void PyGuiApplicationWrapper::pysideInitQtMetaTypes()
{
}

PyGuiApplicationWrapper::PyGuiApplicationWrapper() : Natron::Python::PyGuiApplication()
{
    // ... middle
}

PyGuiApplicationWrapper::~PyGuiApplicationWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Natron_Python_PyGuiApplication_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::Natron::Python::PyGuiApplication >()))
        return -1;

    ::PyGuiApplicationWrapper* cptr{};

    // Call function/method
    {

        if (!PyErr_Occurred()) {
            // PyGuiApplication()
            cptr = new ::PyGuiApplicationWrapper();
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::Natron::Python::PyGuiApplication >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_Natron_Python_PyGuiApplicationFunc_addMenuCommand(PyObject* self, PyObject* args)
{
    ::Natron::Python::PyGuiApplication* cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::Natron::Python::PyGuiApplication *>(Shiboken::Conversions::cppPointer(SbkNatronGuiTypes[SBK_NATRON_PYTHON_PYGUIAPPLICATION_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr, nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject* pyArgs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3)
        goto Sbk_Natron_Python_PyGuiApplicationFunc_addMenuCommand_TypeError;

    if (!PyArg_UnpackTuple(args, "addMenuCommand", 2, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])))
        return {};


    // Overloaded function decisor
    // 0: PyGuiApplication::addMenuCommand(QString,QString)
    // 1: PyGuiApplication::addMenuCommand(QString,QString,Qt::Key,QFlags<Qt::KeyboardModifier>)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // addMenuCommand(QString,QString)
        } else if (numArgs == 4
            && (pythonToCpp[2] = Shiboken::Conversions::isPythonToCppConvertible(*PepType_SGTP(SbkPySide2_QtCoreTypes[SBK_QT_KEY_IDX])->converter, (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::isPythonToCppConvertible(*PepType_SGTP(SbkPySide2_QtCoreTypes[SBK_QFLAGS_QT_KEYBOARDMODIFIER_IDX])->converter, (pyArgs[3])))) {
            overloadId = 1; // addMenuCommand(QString,QString,Qt::Key,QFlags<Qt::KeyboardModifier>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Natron_Python_PyGuiApplicationFunc_addMenuCommand_TypeError;

    // Call function/method
    switch (overloadId) {
        case 0: // addMenuCommand(const QString & grouping, const QString & pythonFunctionName)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!PyErr_Occurred()) {
                // addMenuCommand(QString,QString)
                cppSelf->addMenuCommand(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // addMenuCommand(const QString & grouping, const QString & pythonFunctionName, Qt::Key key, const QFlags<Qt::KeyboardModifier> & modifiers)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::Qt::Key cppArg2 = static_cast< ::Qt::Key>(0);
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QFlags<Qt::KeyboardModifier> cppArg3 = QFlags<Qt::KeyboardModifier>(0);
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (!PyErr_Occurred()) {
                // addMenuCommand(QString,QString,Qt::Key,QFlags<Qt::KeyboardModifier>)
                cppSelf->addMenuCommand(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_Natron_Python_PyGuiApplicationFunc_addMenuCommand_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "NatronGui.Natron.Python.PyGuiApplication.addMenuCommand");
        return {};
}

static PyObject* Sbk_Natron_Python_PyGuiApplicationFunc_errorDialog(PyObject* self, PyObject* args)
{
    ::Natron::Python::PyGuiApplication* cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::Natron::Python::PyGuiApplication *>(Shiboken::Conversions::cppPointer(SbkNatronGuiTypes[SBK_NATRON_PYTHON_PYGUIAPPLICATION_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "errorDialog", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return {};


    // Overloaded function decisor
    // 0: PyGuiApplication::errorDialog(QString,QString)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[1])))) {
        overloadId = 0; // errorDialog(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Natron_Python_PyGuiApplicationFunc_errorDialog_TypeError;

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!PyErr_Occurred()) {
            // errorDialog(QString,QString)
            cppSelf->errorDialog(cppArg0, cppArg1);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_Natron_Python_PyGuiApplicationFunc_errorDialog_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "NatronGui.Natron.Python.PyGuiApplication.errorDialog");
        return {};
}

static PyObject* Sbk_Natron_Python_PyGuiApplicationFunc_getGuiInstance(PyObject* self, PyObject* pyArg)
{
    ::Natron::Python::PyGuiApplication* cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::Natron::Python::PyGuiApplication *>(Shiboken::Conversions::cppPointer(SbkNatronGuiTypes[SBK_NATRON_PYTHON_PYGUIAPPLICATION_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject* pyResult{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: PyGuiApplication::getGuiInstance(int)const
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // getGuiInstance(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Natron_Python_PyGuiApplicationFunc_getGuiInstance_TypeError;

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // getGuiInstance(int)const
            Natron::Python::GuiApp * cppResult = const_cast<const ::Natron::Python::PyGuiApplication*>(cppSelf)->getGuiInstance(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(reinterpret_cast<SbkObjectType *>(SbkNatronGuiTypes[SBK_NATRON_PYTHON_GUIAPP_IDX]), cppResult);

            // Ownership transferences.
            Shiboken::Object::getOwnership(pyResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;

    Sbk_Natron_Python_PyGuiApplicationFunc_getGuiInstance_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "NatronGui.Natron.Python.PyGuiApplication.getGuiInstance");
        return {};
}

static PyObject* Sbk_Natron_Python_PyGuiApplicationFunc_getIcon(PyObject* self, PyObject* pyArg)
{
    ::Natron::Python::PyGuiApplication* cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::Natron::Python::PyGuiApplication *>(Shiboken::Conversions::cppPointer(SbkNatronGuiTypes[SBK_NATRON_PYTHON_PYGUIAPPLICATION_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject* pyResult{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp{};
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: PyGuiApplication::getIcon(Natron::PixmapEnum)const
    if ((pythonToCpp = Shiboken::Conversions::isPythonToCppConvertible(*PepType_SGTP(SbkNatronEngineTypes[SBK_NATRON_PIXMAPENUM_IDX])->converter, (pyArg)))) {
        overloadId = 0; // getIcon(Natron::PixmapEnum)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Natron_Python_PyGuiApplicationFunc_getIcon_TypeError;

    // Call function/method
    {
        ::Natron::PixmapEnum cppArg0{Natron::NATRON_PIXMAP_PLAYER_PREVIOUS};
        pythonToCpp(pyArg, &cppArg0);

        if (!PyErr_Occurred()) {
            // getIcon(Natron::PixmapEnum)const
            QPixmap cppResult = const_cast<const ::Natron::Python::PyGuiApplication*>(cppSelf)->getIcon(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(reinterpret_cast<SbkObjectType *>(SbkPySide2_QtGuiTypes[SBK_QPIXMAP_IDX]), &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;

    Sbk_Natron_Python_PyGuiApplicationFunc_getIcon_TypeError:
        Shiboken::setErrorAboutWrongArguments(pyArg, "NatronGui.Natron.Python.PyGuiApplication.getIcon");
        return {};
}

static PyObject* Sbk_Natron_Python_PyGuiApplicationFunc_informationDialog(PyObject* self, PyObject* args)
{
    ::Natron::Python::PyGuiApplication* cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::Natron::Python::PyGuiApplication *>(Shiboken::Conversions::cppPointer(SbkNatronGuiTypes[SBK_NATRON_PYTHON_PYGUIAPPLICATION_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "informationDialog", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return {};


    // Overloaded function decisor
    // 0: PyGuiApplication::informationDialog(QString,QString)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[1])))) {
        overloadId = 0; // informationDialog(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Natron_Python_PyGuiApplicationFunc_informationDialog_TypeError;

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!PyErr_Occurred()) {
            // informationDialog(QString,QString)
            cppSelf->informationDialog(cppArg0, cppArg1);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_Natron_Python_PyGuiApplicationFunc_informationDialog_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "NatronGui.Natron.Python.PyGuiApplication.informationDialog");
        return {};
}

static PyObject* Sbk_Natron_Python_PyGuiApplicationFunc_questionDialog(PyObject* self, PyObject* args)
{
    ::Natron::Python::PyGuiApplication* cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::Natron::Python::PyGuiApplication *>(Shiboken::Conversions::cppPointer(SbkNatronGuiTypes[SBK_NATRON_PYTHON_PYGUIAPPLICATION_IDX], reinterpret_cast<SbkObject *>(self)));
    PyObject* pyResult{};
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "questionDialog", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return {};


    // Overloaded function decisor
    // 0: PyGuiApplication::questionDialog(QString,QString)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[1])))) {
        overloadId = 0; // questionDialog(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Natron_Python_PyGuiApplicationFunc_questionDialog_TypeError;

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!PyErr_Occurred()) {
            // questionDialog(QString,QString)
            Natron::StandardButtonEnum cppResult = Natron::StandardButtonEnum(cppSelf->questionDialog(cppArg0, cppArg1));
            pyResult = Shiboken::Conversions::copyToPython(*PepType_SGTP(SbkNatronEngineTypes[SBK_NATRON_STANDARDBUTTONENUM_IDX])->converter, &cppResult);
        }
    }

    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;

    Sbk_Natron_Python_PyGuiApplicationFunc_questionDialog_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "NatronGui.Natron.Python.PyGuiApplication.questionDialog");
        return {};
}

static PyObject* Sbk_Natron_Python_PyGuiApplicationFunc_warningDialog(PyObject* self, PyObject* args)
{
    ::Natron::Python::PyGuiApplication* cppSelf = nullptr;
    SBK_UNUSED(cppSelf)
    if (!Shiboken::Object::isValid(self))
        return {};
    cppSelf = reinterpret_cast< ::Natron::Python::PyGuiApplication *>(Shiboken::Conversions::cppPointer(SbkNatronGuiTypes[SBK_NATRON_PYTHON_PYGUIAPPLICATION_IDX], reinterpret_cast<SbkObject *>(self)));
    int overloadId = -1;
    PythonToCppFunc pythonToCpp[] = { nullptr, nullptr };
    SBK_UNUSED(pythonToCpp)
    int numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject* pyArgs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "warningDialog", 2, 2, &(pyArgs[0]), &(pyArgs[1])))
        return {};


    // Overloaded function decisor
    // 0: PyGuiApplication::warningDialog(QString,QString)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::isPythonToCppConvertible(SbkPySide2_QtCoreTypeConverters[SBK_QSTRING_IDX], (pyArgs[1])))) {
        overloadId = 0; // warningDialog(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Natron_Python_PyGuiApplicationFunc_warningDialog_TypeError;

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (!PyErr_Occurred()) {
            // warningDialog(QString,QString)
            cppSelf->warningDialog(cppArg0, cppArg1);
        }
    }

    if (PyErr_Occurred()) {
        return {};
    }
    Py_RETURN_NONE;

    Sbk_Natron_Python_PyGuiApplicationFunc_warningDialog_TypeError:
        Shiboken::setErrorAboutWrongArguments(args, "NatronGui.Natron.Python.PyGuiApplication.warningDialog");
        return {};
}

static PyMethodDef Sbk_Natron_Python_PyGuiApplication_methods[] = {
    {"addMenuCommand", reinterpret_cast<PyCFunction>(Sbk_Natron_Python_PyGuiApplicationFunc_addMenuCommand), METH_VARARGS},
    {"errorDialog", reinterpret_cast<PyCFunction>(Sbk_Natron_Python_PyGuiApplicationFunc_errorDialog), METH_VARARGS},
    {"getGuiInstance", reinterpret_cast<PyCFunction>(Sbk_Natron_Python_PyGuiApplicationFunc_getGuiInstance), METH_O},
    {"getIcon", reinterpret_cast<PyCFunction>(Sbk_Natron_Python_PyGuiApplicationFunc_getIcon), METH_O},
    {"informationDialog", reinterpret_cast<PyCFunction>(Sbk_Natron_Python_PyGuiApplicationFunc_informationDialog), METH_VARARGS},
    {"questionDialog", reinterpret_cast<PyCFunction>(Sbk_Natron_Python_PyGuiApplicationFunc_questionDialog), METH_VARARGS},
    {"warningDialog", reinterpret_cast<PyCFunction>(Sbk_Natron_Python_PyGuiApplicationFunc_warningDialog), METH_VARARGS},

    {nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_Natron_Python_PyGuiApplication_traverse(PyObject* self, visitproc visit, void* arg)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_traverse(self, visit, arg);
}
static int Sbk_Natron_Python_PyGuiApplication_clear(PyObject* self)
{
    return reinterpret_cast<PyTypeObject *>(SbkObject_TypeF())->tp_clear(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType *_Sbk_Natron_Python_PyGuiApplication_Type = nullptr;
static SbkObjectType *Sbk_Natron_Python_PyGuiApplication_TypeF(void)
{
    return _Sbk_Natron_Python_PyGuiApplication_Type;
}

static PyType_Slot Sbk_Natron_Python_PyGuiApplication_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void*>(&SbkDeallocWrapper)},
    {Py_tp_repr,        nullptr},
    {Py_tp_hash,        nullptr},
    {Py_tp_call,        nullptr},
    {Py_tp_str,         nullptr},
    {Py_tp_getattro,    nullptr},
    {Py_tp_setattro,    nullptr},
    {Py_tp_traverse,    reinterpret_cast<void*>(Sbk_Natron_Python_PyGuiApplication_traverse)},
    {Py_tp_clear,       reinterpret_cast<void*>(Sbk_Natron_Python_PyGuiApplication_clear)},
    {Py_tp_richcompare, nullptr},
    {Py_tp_iter,        nullptr},
    {Py_tp_iternext,    nullptr},
    {Py_tp_methods,     reinterpret_cast<void*>(Sbk_Natron_Python_PyGuiApplication_methods)},
    {Py_tp_getset,      nullptr},
    {Py_tp_init,        reinterpret_cast<void*>(Sbk_Natron_Python_PyGuiApplication_Init)},
    {Py_tp_new,         reinterpret_cast<void*>(SbkObjectTpNew)},
    {0, nullptr}
};
static PyType_Spec Sbk_Natron_Python_PyGuiApplication_spec = {
    "NatronGui.Natron.Python.PyGuiApplication",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_GC,
    Sbk_Natron_Python_PyGuiApplication_slots
};

} //extern "C"

static void* Sbk_Natron_Python_PyGuiApplication_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType< ::Natron::Python::PyCoreApplication >()))
        return dynamic_cast< ::Natron::Python::PyGuiApplication*>(reinterpret_cast< ::Natron::Python::PyCoreApplication*>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void PyGuiApplication_PythonToCpp_PyGuiApplication_PTR(PyObject* pyIn, void* cppOut) {
    Shiboken::Conversions::pythonToCppPointer(Sbk_Natron_Python_PyGuiApplication_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_PyGuiApplication_PythonToCpp_PyGuiApplication_PTR_Convertible(PyObject* pyIn) {
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, reinterpret_cast<PyTypeObject*>(Sbk_Natron_Python_PyGuiApplication_TypeF())))
        return PyGuiApplication_PythonToCpp_PyGuiApplication_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject* PyGuiApplication_PTR_CppToPython_PyGuiApplication(const void* cppIn) {
    auto pyOut = reinterpret_cast<PyObject*>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    bool changedTypeName = false;
    auto tCppIn = reinterpret_cast<const ::Natron::Python::PyGuiApplication *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    auto sbkType = Shiboken::ObjectType::typeForTypeName(typeName);
    if (sbkType && Shiboken::ObjectType::hasSpecialCastFunction(sbkType)) {
        typeName = typeNameOf(tCppIn);
        changedTypeName = true;
     }
    PyObject *result = Shiboken::Object::newObject(Sbk_Natron_Python_PyGuiApplication_TypeF(), const_cast<void*>(cppIn), false, /* exactType */ changedTypeName, typeName);
    if (changedTypeName)
        delete [] typeName;
    return result;
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
static const char *Natron_Python_PyGuiApplication_SignatureStrings[] = {
    "NatronGui.Natron.Python.PyGuiApplication()",
    "1:NatronGui.Natron.Python.PyGuiApplication.addMenuCommand(grouping:QString,pythonFunctionName:QString)",
    "0:NatronGui.Natron.Python.PyGuiApplication.addMenuCommand(grouping:QString,pythonFunctionName:QString,key:PySide2.QtCore.Qt.Key,modifiers:PySide2.QtCore.Qt.KeyboardModifiers)",
    "NatronGui.Natron.Python.PyGuiApplication.errorDialog(title:QString,message:QString)",
    "NatronGui.Natron.Python.PyGuiApplication.getGuiInstance(idx:int)->NatronGui.Natron.Python.GuiApp",
    "NatronGui.Natron.Python.PyGuiApplication.getIcon(val:NatronEngine.Natron.PixmapEnum)->PySide2.QtGui.QPixmap",
    "NatronGui.Natron.Python.PyGuiApplication.informationDialog(title:QString,message:QString)",
    "NatronGui.Natron.Python.PyGuiApplication.questionDialog(title:QString,message:QString)->NatronEngine.Natron.StandardButtonEnum",
    "NatronGui.Natron.Python.PyGuiApplication.warningDialog(title:QString,message:QString)",
    nullptr}; // Sentinel

void init_Natron_Python_PyGuiApplication(PyObject* module)
{
    _Sbk_Natron_Python_PyGuiApplication_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "PyGuiApplication",
        "Natron::Python::PyGuiApplication*",
        &Sbk_Natron_Python_PyGuiApplication_spec,
        Natron_Python_PyGuiApplication_SignatureStrings,
        &Shiboken::callCppDestructor< ::Natron::Python::PyGuiApplication >,
        reinterpret_cast<SbkObjectType *>(SbkNatronEngineTypes[SBK_NATRON_PYTHON_PYCOREAPPLICATION_IDX]),
        0,
        0    );
    
    SbkNatronGuiTypes[SBK_NATRON_PYTHON_PYGUIAPPLICATION_IDX]
        = reinterpret_cast<PyTypeObject*>(Sbk_Natron_Python_PyGuiApplication_TypeF());

    // Register Converter
    SbkConverter* converter = Shiboken::Conversions::createConverter(Sbk_Natron_Python_PyGuiApplication_TypeF(),
        PyGuiApplication_PythonToCpp_PyGuiApplication_PTR,
        is_PyGuiApplication_PythonToCpp_PyGuiApplication_PTR_Convertible,
        PyGuiApplication_PTR_CppToPython_PyGuiApplication);

    Shiboken::Conversions::registerConverterName(converter, "Natron::Python::PyGuiApplication");
    Shiboken::Conversions::registerConverterName(converter, "Natron::Python::PyGuiApplication*");
    Shiboken::Conversions::registerConverterName(converter, "Natron::Python::PyGuiApplication&");
    Shiboken::Conversions::registerConverterName(converter, "Python::PyGuiApplication");
    Shiboken::Conversions::registerConverterName(converter, "Python::PyGuiApplication*");
    Shiboken::Conversions::registerConverterName(converter, "Python::PyGuiApplication&");
    Shiboken::Conversions::registerConverterName(converter, "PyGuiApplication");
    Shiboken::Conversions::registerConverterName(converter, "PyGuiApplication*");
    Shiboken::Conversions::registerConverterName(converter, "PyGuiApplication&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Natron::Python::PyGuiApplication).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(::PyGuiApplicationWrapper).name());


    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(Sbk_Natron_Python_PyGuiApplication_TypeF(), &Sbk_Natron_Python_PyGuiApplication_typeDiscovery);


    PyGuiApplicationWrapper::pysideInitQtMetaTypes();
}
